Post

This is a fun one: I just sent go.dev/cl/790740, which elides method wrappers for embedded types at offset zero, common for mixins/inherited data types. Doing this removes 60 _thousand_ method wrappers from tsgo's AST package, dropping the compilation of our main exe from 49s to 28s on my machine.

The trybots passed, so I assume not, or otherwise it's untested... I'll go figure that out when I have time. I'm hoping not because this perf boost is too good

Ah, it doesn't change anything, because the wrapper is already not shown in the printout, the original methods are!

0 reposts0 likes

No replies yet.